@@ -371,6 +371,42 @@ impl Date {
 
         year
     }
+
+    #[inline]
+    pub(crate) fn round_week_internal(self, year: i32) -> Result<Date> {
+        const WEEK_TABLE: [(DateSubMethod, i32); 8] = [
+            (current_date, 0),
+            (sub_to_date, 1),
+            (sub_to_date, 2),
+            (sub_to_date, 3),
+            (sub_to_date, -3),
+            (sub_to_date, -2),
+            (sub_to_date, -1),
+            (sub_to_date, 0), // Unreachable
+        ];
+
+        let week_day = self.sub_date(unsafe { Date::from_ymd_unchecked(year, 1, 1) }) % 7;
+        let (to_first_date_of_week, remain_day) = WEEK_TABLE[week_day as usize];
+        to_first_date_of_week(self, remain_day)
+    }
+
+    #[inline]
+    pub(crate) fn round_month_start_week_internal(self, day: i32) -> Result<Date> {
+        const MONTH_START_WEEK_TABLE: [(DateSubMethod, i32); 8] = [
+            (sub_to_date, -1),
+            (current_date, 0),
+            (sub_to_date, 1),
+            (sub_to_date, 2),
+            (sub_to_date, 3),
+            (sub_to_date, -3),
+            (sub_to_date, -2),
+            (sub_to_date, 0), // Unreachable
+        ];
+
+        let week_day = day % 7;
+        let (to_first_date_of_week, remain_day) = MONTH_START_WEEK_TABLE[week_day as usize];
+        to_first_date_of_week(self, remain_day)
+    }
 }
 
 impl Trunc for Date {
@@ -515,13 +551,14 @@ impl Round for Date {
 
     #[inline]
     fn round_iso_year(self) -> Result<Self> {
-        let (year, month, day) = self.extract();
+        let (year, month, _) = self.extract();
         let mut date = self;
         if month >= 7 {
             if year == DATE_MAX_YEAR {
                 return Err(Error::DateOutOfRange);
             }
-            date = unsafe { Date::from_ymd_unchecked(year + 1, month, day) };
+            // Sets the month and date into the first week.
+            date = unsafe { Date::from_ymd_unchecked(year + 1, 1, 4) };
         }
         date.trunc_iso_year()
     }
@@ -572,21 +609,7 @@ impl Round for Date {
 
     #[inline]
     fn round_week(self) -> Result<Self> {
-        const WEEK_TABLE: [(DateSubMethod, i32); 8] = [
-            (current_date, 0),
-            (sub_to_date, 1),
-            (sub_to_date, 2),
-            (sub_to_date, 3),
-            (sub_to_date, -3),
-            (sub_to_date, -2),
-            (sub_to_date, -1),
-            (sub_to_date, 0), // Unreachable
-        ];
-
-        let week_day =
-            self.sub_date(unsafe { Date::from_ymd_unchecked(self.year().unwrap(), 1, 1) }) % 7;
-        let (to_first_date_of_week, remain_day) = WEEK_TABLE[week_day as usize];
-        to_first_date_of_week(self, remain_day)
+        self.round_week_internal(self.year().unwrap())
     }
 
     #[inline]
@@ -609,20 +632,7 @@ impl Round for Date {
 
     #[inline]
     fn round_month_start_week(self) -> Result<Self> {
-        const MONTH_START_WEEK_TABLE: [(DateSubMethod, i32); 8] = [
-            (sub_to_date, -1),
-            (current_date, 0),
-            (sub_to_date, 1),
-            (sub_to_date, 2),
-            (sub_to_date, 3),
-            (sub_to_date, -3),
-            (sub_to_date, -2),
-            (sub_to_date, 0), // Unreachable
-        ];
-
-        let week_day = self.day().unwrap() % 7;
-        let (to_first_date_of_week, remain_day) = MONTH_START_WEEK_TABLE[week_day as usize];
-        to_first_date_of_week(self, remain_day)
+        self.round_month_start_week_internal(self.day().unwrap())
     }
 
     #[inline]
@@ -1357,9 +1367,8 @@ mod tests {
             generate_date(1, 1, 1),
             generate_date(1, 1, 1).round_iso_year().unwrap()
         );
-        // First year of Julian date, and last date of range is overflow
         assert_eq!(
-            generate_date(1584, 12, 31),
+            generate_date(1584, 1, 2),
             generate_date(1583, 12, 31).round_iso_year().unwrap()
         );
         assert_eq!(generate_date(1996, 12, 30), dt.round_iso_year().unwrap());
@@ -1377,10 +1386,22 @@ mod tests {
             generate_date(2019, 12, 30),
             generate_date(2019, 12, 31).round_iso_year().unwrap()
         );
+        assert_eq!(
+            generate_date(2018, 12, 31),
+            generate_date(2018, 12, 30).round_iso_year().unwrap()
+        );
+        assert_eq!(
+            generate_date(2018, 12, 31),
+            generate_date(2018, 12, 31).round_iso_year().unwrap()
+        );
         // Next year
         assert_eq!(
-            generate_date(2019, 12, 30),
-            generate_date(2018, 12, 31).round_iso_year().unwrap()
+            generate_date(2001, 1, 1),
+            generate_date(2000, 12, 30).round_iso_year().unwrap()
+        );
+        assert_eq!(
+            generate_date(2001, 1, 1),
+            generate_date(2000, 12, 31).round_iso_year().unwrap()
         );
 
         assert_eq!(generate_date(1996, 10, 1), dt.round_quarter().unwrap());
