@@ -703,6 +703,33 @@ mod tests {
                 assert_eq!(dt, date);
             }
 
+            // Absence of time
+            {
+                let dt = generate_date(2021, 12, 15, 0, 0, 0);
+                let date = Date::parse("2021-12-15", "yyyy-mm-dd hh24:mi:ss").unwrap();
+                assert_eq!(dt, date);
+
+                let dt = generate_date(2021, 12, 15, 11, 0, 0);
+                let date = Date::parse("2021-12-15 11", "yyyy-mm-dd hh24:mi:ss").unwrap();
+                assert_eq!(dt, date);
+
+                let dt = generate_date(2021, 12, 15, 11, 23, 0);
+                let date = Date::parse("2021-12-15 11:23", "yyyy-mm-dd hh24:mi:ss").unwrap();
+                assert_eq!(dt, date);
+
+                let dt = generate_date(2021, 12, 15, 12, 0, 0);
+                let date = Date::parse("2021-12-15", "yyyy-mm-dd hh:mi:ss").unwrap();
+                assert_eq!(dt, date);
+
+                let dt = generate_date(2021, 12, 15, 11, 0, 0);
+                let date = Date::parse("2021-12-15 11", "yyyy-mm-dd hh:mi:ss").unwrap();
+                assert_eq!(dt, date);
+
+                let dt = generate_date(2021, 12, 15, 11, 23, 0);
+                let date = Date::parse("2021-12-15 11:23", "yyyy-mm-dd hh:mi:ss").unwrap();
+                assert_eq!(dt, date);
+            }
+
             // Short format
             {
                 let date = generate_date(1234, 8, 6, 7, 8, 9);
